@@ -18,6 +18,18 @@ Quick and dirty …
         [ "The", "last", "value", "is", "returned." ];
     > );
 
+… or, something a bit fancier:
+
+    my $js = JavaScript::QuickJS->new()->std()->helpers();
+
+    $js->eval_module( q/
+        import * as std from 'std';
+
+        for (const [key, value] of Object.entries(std.getenviron())) {
+            console.log(key, value);
+        }
+    / );
+
 =head1 DESCRIPTION
 
 This library embeds Fabrice Bellard’s L<QuickJS|https://bellard.org/quickjs>
@@ -35,7 +47,7 @@ your system.
 
 use XSLoader;
 
-our $VERSION = '0.14_90';
+our $VERSION = '0.16_01';
 
 XSLoader::load( __PACKAGE__, $VERSION );
 
@@ -108,6 +120,7 @@ Returns I<OBJ>.
 =head2 $obj = I<OBJ>->std()
 
 Enables (but does I<not> import) QuickJS’s C<std> module.
+See L</SYNOPSIS> above for example usage.
 
 Returns I<OBJ>.
 
@@ -177,9 +190,9 @@ This module converts returned values from JavaScript thus:
 
 =item * “Plain” objects become Perl hash references.
 
-=item * Function objects become Perl L<JavaScript::QuickJS::Function> objects.
-
-=item * RegExp objects become Perl L<JavaScript::QuickJS::RegExp> objects.
+=item * Function, RegExp, and Date objects become Perl
+L<JavaScript::QuickJS::Function>, L<JavaScript::QuickJS::RegExp>,
+and L<JavaScript::QuickJS::Date> objects, respectively.
 
 =item * Behaviour is B<UNDEFINED> for other object types.
 
@@ -210,11 +223,9 @@ to prevent your Perl “number” from becoming a JavaScript string. (Even in
 
 =item * Perl code references become JavaScript functions.
 
-=item * L<JavaScript::QuickJS::Function> objects become their original
-JavaScript C<Function> objects.
-
-=item * L<JavaScript::QuickJS::RegExp> objects become their original
-JavaScript C<RegExp> objects.
+=item * Perl L<JavaScript::QuickJS::Function>, L<JavaScript::QuickJS::RegExp>,
+and L<JavaScript::QuickJS::Date> objects become their original
+JavaScript objects.
 
 =item * Anything else triggers an exception.
 
@@ -363,4 +374,18 @@ under the L<MIT license|https://opensource.org/licenses/MIT>.
 
 =cut
 
+#----------------------------------------------------------------------
+
+package JavaScript::QuickJS::JSObject;
+
+package JavaScript::QuickJS::RegExp;
+
+our @ISA;
+BEGIN { @ISA = 'JavaScript::QuickJS::JSObject' };
+
+package JavaScript::QuickJS::Function;
+
+our @ISA;
+BEGIN { @ISA = 'JavaScript::QuickJS::JSObject' };
+
 1;
